#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-main-window.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-main-window.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-main-window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6octave11main_windowE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::main_window::qt_create_metaobjectdata<qt_meta_tag_ZN6octave11main_windowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::main_window",
        "close_gui_signal",
        "",
        "active_dock_changed",
        "octave_dock_widget*",
        "editor_focus_changed",
        "settings_changed",
        "init_terminal_size_signal",
        "init_window_menu",
        "new_file_signal",
        "open_file_signal",
        "file",
        "enc",
        "line",
        "step_into_file_signal",
        "show_community_news_signal",
        "serial",
        "show_release_notes_signal",
        "update_gui_lexer_signal",
        "insert_debugger_pointer_signal",
        "delete_debugger_pointer_signal",
        "update_breakpoint_marker_signal",
        "insert",
        "cond",
        "copyClipboard_signal",
        "pasteClipboard_signal",
        "selectAll_signal",
        "undo_signal",
        "add_actions_signal",
        "QList<QAction*>",
        "action_list",
        "warning_function_not_found_signal",
        "message",
        "interpreter_event",
        "fcn_callback",
        "fcn",
        "meth_callback",
        "meth",
        "execute_command_signal",
        "command",
        "update_prompt_signal",
        "prompt",
        "focus_command_window",
        "focus_changed",
        "QWidget*",
        "w_old",
        "w_new",
        "focus_window",
        "win_name",
        "request_reload_settings",
        "report_status_message",
        "statusMessage",
        "handle_save_workspace_request",
        "handle_load_workspace_request",
        "handle_open_any_request",
        "handle_clear_workspace_request",
        "handle_clear_command_window_request",
        "handle_clear_history_request",
        "handle_undo_request",
        "modify_path",
        "dir_list",
        "rm",
        "subdirs",
        "edit_mfile",
        "file_remove_proxy",
        "o",
        "n",
        "open_online_documentation_page",
        "open_bug_tracker_page",
        "open_octave_packages_page",
        "open_contribute_page",
        "open_donate_page",
        "process_settings_dialog_request",
        "desired_tab",
        "show_about_octave",
        "notice_settings",
        "update_by_worker",
        "getFusionDarkPalette",
        "QPalette",
        "prepare_to_exit",
        "go_to_previous_widget",
        "reset_windows",
        "do_reset_windows",
        "show",
        "save",
        "force_all",
        "update_octave_directory",
        "dir",
        "browse_for_directory",
        "set_current_working_directory",
        "change_directory_up",
        "accept_directory_line_edit",
        "execute_command_in_terminal",
        "run_file_in_terminal",
        "QFileInfo",
        "info",
        "opts",
        "handle_new_figure_request",
        "handle_enter_debugger",
        "handle_exit_debugger",
        "debug_continue",
        "debug_step_into",
        "debug_step_over",
        "debug_step_out",
        "debug_quit",
        "editor_tabs_changed",
        "request_open_file",
        "request_new_script",
        "commands",
        "request_new_function",
        "triggered",
        "handle_edit_mfile_request",
        "name",
        "curr_dir",
        "handle_insert_debugger_pointer_request",
        "handle_delete_debugger_pointer_request",
        "handle_update_breakpoint_marker_request",
        "read_settings",
        "init_terminal_size",
        "set_window_layout",
        "write_settings",
        "copyClipboard",
        "pasteClipboard",
        "selectAll",
        "handle_gui_status_update",
        "feature",
        "status",
        "focus_console_after_command",
        "profiler_session",
        "profiler_session_resume",
        "profiler_stop",
        "handle_profiler_status_update",
        "profiler_show",
        "handle_octave_ready",
        "handle_set_path_dialog_request",
        "find_files",
        "startdir",
        "find_files_finished",
        "set_screen_size",
        "ht",
        "wd",
        "clipboard_has_changed",
        "clear_clipboard",
        "get_dock_widget_list",
        "QList<octave_dock_widget*>",
        "disable_menu_shortcuts",
        "disable",
        "restore_create_file_setting",
        "set_file_encoding",
        "new_encoding",
        "warning_function_not_found"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'close_gui_signal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'active_dock_changed'
        QtMocHelpers::SignalData<void(octave_dock_widget *, octave_dock_widget *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'editor_focus_changed'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'settings_changed'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'init_terminal_size_signal'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'init_window_menu'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'new_file_signal'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'open_file_signal'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'open_file_signal'
        QtMocHelpers::SignalData<void(const QString &, const QString &, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'step_into_file_signal'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'show_community_news_signal'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'show_release_notes_signal'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'update_gui_lexer_signal'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'insert_debugger_pointer_signal'
        QtMocHelpers::SignalData<void(const QString &, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'delete_debugger_pointer_signal'
        QtMocHelpers::SignalData<void(const QString &, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'update_breakpoint_marker_signal'
        QtMocHelpers::SignalData<void(bool, const QString &, int, const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 }, { QMetaType::QString, 11 }, { QMetaType::Int, 13 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'copyClipboard_signal'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pasteClipboard_signal'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAll_signal'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undo_signal'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'add_actions_signal'
        QtMocHelpers::SignalData<void(QList<QAction*>)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'warning_function_not_found_signal'
        QtMocHelpers::SignalData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const fcn_callback &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const meth_callback &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'execute_command_signal'
        QtMocHelpers::SignalData<void(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Signal 'update_prompt_signal'
        QtMocHelpers::SignalData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'focus_command_window'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focus_changed'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { 0x80000000 | 44, 46 },
        }}),
        // Slot 'focus_window'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'request_reload_settings'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'report_status_message'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'handle_save_workspace_request'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_load_workspace_request'
        QtMocHelpers::SlotData<void(const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'handle_load_workspace_request'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'handle_open_any_request'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'handle_open_any_request'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'handle_clear_workspace_request'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_clear_command_window_request'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_clear_history_request'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_undo_request'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'modify_path'
        QtMocHelpers::SlotData<void(const QStringList &, bool, bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 60 }, { QMetaType::Bool, 61 }, { QMetaType::Bool, 62 },
        }}),
        // Slot 'edit_mfile'
        QtMocHelpers::SlotData<void(const QString &, int)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'file_remove_proxy'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 66 },
        }}),
        // Slot 'open_online_documentation_page'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open_bug_tracker_page'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open_octave_packages_page'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open_contribute_page'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open_donate_page'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'process_settings_dialog_request'
        QtMocHelpers::SlotData<void(const QString &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 73 },
        }}),
        // Slot 'process_settings_dialog_request'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'show_about_octave'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void(bool)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 76 },
        }}),
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'getFusionDarkPalette'
        QtMocHelpers::SlotData<QPalette()>(77, 2, QMC::AccessPublic, 0x80000000 | 78),
        // Slot 'prepare_to_exit'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'go_to_previous_widget'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset_windows'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'do_reset_windows'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 83 }, { QMetaType::Bool, 84 }, { QMetaType::Bool, 85 },
        }}),
        // Slot 'do_reset_windows'
        QtMocHelpers::SlotData<void(bool, bool)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 83 }, { QMetaType::Bool, 84 },
        }}),
        // Slot 'do_reset_windows'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'do_reset_windows'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'update_octave_directory'
        QtMocHelpers::SlotData<void(const QString &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 87 },
        }}),
        // Slot 'browse_for_directory'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'set_current_working_directory'
        QtMocHelpers::SlotData<void(const QString &)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 87 },
        }}),
        // Slot 'change_directory_up'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept_directory_line_edit'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'execute_command_in_terminal'
        QtMocHelpers::SlotData<void(const QString &)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 87 },
        }}),
        // Slot 'run_file_in_terminal'
        QtMocHelpers::SlotData<void(const QFileInfo &, int)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 94, 95 }, { QMetaType::Int, 96 },
        }}),
        // Slot 'handle_new_figure_request'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_enter_debugger'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_exit_debugger'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debug_continue'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debug_step_into'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debug_step_over'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debug_step_out'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'debug_quit'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editor_tabs_changed'
        QtMocHelpers::SlotData<void(bool, bool)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'request_open_file'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'request_new_script'
        QtMocHelpers::SlotData<void(const QString &)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 108 },
        }}),
        // Slot 'request_new_script'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'request_new_function'
        QtMocHelpers::SlotData<void(bool)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 110 },
        }}),
        // Slot 'request_new_function'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'handle_edit_mfile_request'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 112 }, { QMetaType::QString, 11 }, { QMetaType::QString, 113 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'handle_insert_debugger_pointer_request'
        QtMocHelpers::SlotData<void(const QString &, int)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'handle_delete_debugger_pointer_request'
        QtMocHelpers::SlotData<void(const QString &, int)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'handle_update_breakpoint_marker_request'
        QtMocHelpers::SlotData<void(bool, const QString &, int, const QString &)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 }, { QMetaType::QString, 11 }, { QMetaType::Int, 13 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'read_settings'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init_terminal_size'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'set_window_layout'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'write_settings'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyClipboard'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_gui_status_update'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(124, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 125 }, { QMetaType::QString, 126 },
        }}),
        // Slot 'focus_console_after_command'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'profiler_session'
        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'profiler_session_resume'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'profiler_stop'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_profiler_status_update'
        QtMocHelpers::SlotData<void(bool)>(131, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'profiler_show'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_octave_ready'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_set_path_dialog_request'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'find_files'
        QtMocHelpers::SlotData<void(const QString &)>(135, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 136 },
        }}),
        // Slot 'find_files'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'find_files_finished'
        QtMocHelpers::SlotData<void(int)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'set_screen_size'
        QtMocHelpers::SlotData<void(int, int)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 139 }, { QMetaType::Int, 140 },
        }}),
        // Slot 'clipboard_has_changed'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear_clipboard'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'get_dock_widget_list'
        QtMocHelpers::SlotData<QList<octave_dock_widget*>()>(143, 2, QMC::AccessPublic, 0x80000000 | 144),
        // Slot 'disable_menu_shortcuts'
        QtMocHelpers::SlotData<void(bool)>(145, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 146 },
        }}),
        // Slot 'restore_create_file_setting'
        QtMocHelpers::SlotData<void()>(147, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'set_file_encoding'
        QtMocHelpers::SlotData<void(const QString &)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 149 },
        }}),
        // Slot 'warning_function_not_found'
        QtMocHelpers::SlotData<void(const QString &)>(150, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<main_window, qt_meta_tag_ZN6octave11main_windowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::main_window::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave11main_windowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave11main_windowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave11main_windowE_t>.metaTypes,
    nullptr
} };

void octave::main_window::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<main_window *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->close_gui_signal(); break;
        case 1: _t->active_dock_changed((*reinterpret_cast<std::add_pointer_t<octave_dock_widget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<octave_dock_widget*>>(_a[2]))); break;
        case 2: _t->editor_focus_changed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->settings_changed(); break;
        case 4: _t->init_terminal_size_signal(); break;
        case 5: _t->init_window_menu(); break;
        case 6: _t->new_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->open_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->open_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->step_into_file_signal(); break;
        case 10: _t->show_community_news_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->show_release_notes_signal(); break;
        case 12: _t->update_gui_lexer_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->insert_debugger_pointer_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->delete_debugger_pointer_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->update_breakpoint_marker_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 16: _t->copyClipboard_signal(); break;
        case 17: _t->pasteClipboard_signal(); break;
        case 18: _t->selectAll_signal(); break;
        case 19: _t->undo_signal(); break;
        case 20: _t->add_actions_signal((*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[1]))); break;
        case 21: _t->warning_function_not_found_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
        case 23: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
        case 24: _t->execute_command_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->update_prompt_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->focus_command_window(); break;
        case 27: _t->focus_changed((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 28: _t->focus_window((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->request_reload_settings(); break;
        case 30: _t->report_status_message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->handle_save_workspace_request(); break;
        case 32: _t->handle_load_workspace_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->handle_load_workspace_request(); break;
        case 34: _t->handle_open_any_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->handle_open_any_request(); break;
        case 36: _t->handle_clear_workspace_request(); break;
        case 37: _t->handle_clear_command_window_request(); break;
        case 38: _t->handle_clear_history_request(); break;
        case 39: _t->handle_undo_request(); break;
        case 40: _t->modify_path((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 41: _t->edit_mfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 42: _t->file_remove_proxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 43: _t->open_online_documentation_page(); break;
        case 44: _t->open_bug_tracker_page(); break;
        case 45: _t->open_octave_packages_page(); break;
        case 46: _t->open_contribute_page(); break;
        case 47: _t->open_donate_page(); break;
        case 48: _t->process_settings_dialog_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->process_settings_dialog_request(); break;
        case 50: _t->show_about_octave(); break;
        case 51: _t->notice_settings((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->notice_settings(); break;
        case 53: { QPalette _r = _t->getFusionDarkPalette();
            if (_a[0]) *reinterpret_cast<QPalette*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->prepare_to_exit(); break;
        case 55: _t->go_to_previous_widget(); break;
        case 56: _t->reset_windows(); break;
        case 57: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 58: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 59: _t->do_reset_windows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->do_reset_windows(); break;
        case 61: _t->update_octave_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 62: _t->browse_for_directory(); break;
        case 63: _t->set_current_working_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 64: _t->change_directory_up(); break;
        case 65: _t->accept_directory_line_edit(); break;
        case 66: _t->execute_command_in_terminal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 67: _t->run_file_in_terminal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 68: _t->handle_new_figure_request(); break;
        case 69: _t->handle_enter_debugger(); break;
        case 70: _t->handle_exit_debugger(); break;
        case 71: _t->debug_continue(); break;
        case 72: _t->debug_step_into(); break;
        case 73: _t->debug_step_over(); break;
        case 74: _t->debug_step_out(); break;
        case 75: _t->debug_quit(); break;
        case 76: _t->editor_tabs_changed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 77: _t->request_open_file(); break;
        case 78: _t->request_new_script((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 79: _t->request_new_script(); break;
        case 80: _t->request_new_function((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: _t->request_new_function(); break;
        case 82: _t->handle_edit_mfile_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 83: _t->handle_insert_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 84: _t->handle_delete_debugger_pointer_request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 85: _t->handle_update_breakpoint_marker_request((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 86: _t->read_settings(); break;
        case 87: _t->init_terminal_size(); break;
        case 88: _t->set_window_layout(); break;
        case 89: _t->write_settings(); break;
        case 90: _t->copyClipboard(); break;
        case 91: _t->pasteClipboard(); break;
        case 92: _t->selectAll(); break;
        case 93: _t->handle_gui_status_update((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 94: _t->focus_console_after_command(); break;
        case 95: _t->profiler_session(); break;
        case 96: _t->profiler_session_resume(); break;
        case 97: _t->profiler_stop(); break;
        case 98: _t->handle_profiler_status_update((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 99: _t->profiler_show(); break;
        case 100: _t->handle_octave_ready(); break;
        case 101: _t->handle_set_path_dialog_request(); break;
        case 102: _t->find_files((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 103: _t->find_files(); break;
        case 104: _t->find_files_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 105: _t->set_screen_size((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 106: _t->clipboard_has_changed(); break;
        case 107: _t->clear_clipboard(); break;
        case 108: { QList<octave_dock_widget*> _r = _t->get_dock_widget_list();
            if (_a[0]) *reinterpret_cast<QList<octave_dock_widget*>*>(_a[0]) = std::move(_r); }  break;
        case 109: _t->disable_menu_shortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 110: _t->restore_create_file_setting(); break;
        case 111: _t->set_file_encoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 112: _t->warning_function_not_found((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< octave_dock_widget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::close_gui_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(octave_dock_widget * , octave_dock_widget * )>(_a, &main_window::active_dock_changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(bool )>(_a, &main_window::editor_focus_changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::settings_changed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::init_terminal_size_signal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::init_window_menu, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & )>(_a, &main_window::new_file_signal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & )>(_a, &main_window::open_file_signal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & , const QString & , int )>(_a, &main_window::open_file_signal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::step_into_file_signal, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(int )>(_a, &main_window::show_community_news_signal, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::show_release_notes_signal, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(bool )>(_a, &main_window::update_gui_lexer_signal, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & , int )>(_a, &main_window::insert_debugger_pointer_signal, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & , int )>(_a, &main_window::delete_debugger_pointer_signal, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(bool , const QString & , int , const QString & )>(_a, &main_window::update_breakpoint_marker_signal, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::copyClipboard_signal, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::pasteClipboard_signal, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::selectAll_signal, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)()>(_a, &main_window::undo_signal, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(QList<QAction*> )>(_a, &main_window::add_actions_signal, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & )>(_a, &main_window::warning_function_not_found_signal, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const fcn_callback & )>(_a, &main_window::interpreter_event, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const meth_callback & )>(_a, &main_window::interpreter_event, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & )>(_a, &main_window::execute_command_signal, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (main_window::*)(const QString & )>(_a, &main_window::update_prompt_signal, 25))
            return;
    }
}

const QMetaObject *octave::main_window::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::main_window::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave11main_windowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int octave::main_window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 113)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 113;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 113)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 113;
    }
    return _id;
}

// SIGNAL 0
void octave::main_window::close_gui_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::main_window::active_dock_changed(octave_dock_widget * _t1, octave_dock_widget * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void octave::main_window::editor_focus_changed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void octave::main_window::settings_changed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void octave::main_window::init_terminal_size_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void octave::main_window::init_window_menu()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void octave::main_window::new_file_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void octave::main_window::open_file_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void octave::main_window::open_file_signal(const QString & _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void octave::main_window::step_into_file_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void octave::main_window::show_community_news_signal(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void octave::main_window::show_release_notes_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void octave::main_window::update_gui_lexer_signal(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void octave::main_window::insert_debugger_pointer_signal(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void octave::main_window::delete_debugger_pointer_signal(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void octave::main_window::update_breakpoint_marker_signal(bool _t1, const QString & _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 16
void octave::main_window::copyClipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void octave::main_window::pasteClipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void octave::main_window::selectAll_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void octave::main_window::undo_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void octave::main_window::add_actions_signal(QList<QAction*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void octave::main_window::warning_function_not_found_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void octave::main_window::interpreter_event(const fcn_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void octave::main_window::interpreter_event(const meth_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void octave::main_window::execute_command_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void octave::main_window::update_prompt_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}
QT_WARNING_POP
